@@ -223,10 +223,10 @@ parallel_env = parallel_wrapper_fn(env)
 class raw_env(AECEnv, EzPickle):
     # class env(MultiAgentEnv):
     metadata = {
-        'render.modes': ['human', "rgb_array"],
+        'render_modes': ['human', "rgb_array"],
         'name': "cooperative_pong_v5",
         'is_parallelizable': True,
-        'video.frames_per_second': FPS
+        'render_fps': FPS
     }
 
     def __init__(self, **kwargs):
