@@ -101,10 +101,10 @@ class raw_env(AECEnv, EzPickle):
         self.sprite_list = ["sprites/alien", "sprites/drone", "sprites/glowy", "sprites/reptile", "sprites/ufo", "sprites/bunny", "sprites/robot", "sprites/tank"]
         self.sprite_img_heights = [40, 40, 46, 48, 32, 54, 48, 53]
         self.metadata = {
-            'render.modes': ['human', "rgb_array"],
+            'render_modes': ['human', "rgb_array"],
             'name': "prison_v4",
             'is_parallelizable': True,
-            'video.frames_per_second': FPS,
+            'render_fps': FPS,
         }
         self.infos = {}
         self.rendering = False
