@@ -68,7 +68,7 @@ class Backgammon:
 
     def could_bear_off(self, player, roll):
         # I could bear off if I use one roll to move the only checkers outside my home board, to my home board. Then I can bear off with the other roll
-        tot = sum([self.board[position][0] for position in self.players_home_positions[player] if player == self.board[position][1]])
+        tot = sum(self.board[position][0] for position in self.players_home_positions[player] if player == self.board[position][1])
         threshold = 15 - 1 if len(roll) == 2 else 15 - 3
         return tot >= (threshold - self.off[player])
 
@@ -90,11 +90,11 @@ class Backgammon:
         plays = set()
 
         positions = self.players_positions[player]
-        combinations_positions = set(itertools.combinations(positions, 2))
+        combinations_positions = list(itertools.combinations(positions, 2))
 
         for s in positions:
             if self.board[s][0] > 1:
-                combinations_positions.add((s, s))
+                combinations_positions.append((s, s))
 
             if self.is_valid(player, s + roll[0]) and self.is_valid(player, s + roll[0] + roll[1]):
                 plays.add(((s, s + roll[0]), (s + roll[0], s + roll[0] + roll[1])))
@@ -393,7 +393,7 @@ class Backgammon:
                     plays.add(((s, t2), (s1, clamp(s1 + r1))))
 
             # checkers that are higher than the maximum roll (i.e. if the roll is (2,3), the highest checkers are the checkers in position 4,5,6,... (if player WHITE is the current player))
-            highest_src = set([s for s in active_positions if comp2(player, s, s1)])
+            highest_src = {s for s in active_positions if comp2(player, s, s1)}
 
             # If there are no checkers on higher-numbered points,...
             if len(highest_src) == 0:
@@ -446,7 +446,7 @@ class Backgammon:
 
                         if s1_best is not None:
 
-                            higher_src1 = set([s for s in tmp if comp2(player, s, s1_best)])
+                            higher_src1 = {s for s in tmp if comp2(player, s, s1_best)}
 
                             if len(higher_src1) == 0:
                                 plays.add((move, (s1_best, clamp(s1_best + r1))))
@@ -463,14 +463,14 @@ class Backgammon:
 
                         if s1_best is not None:
 
-                            higher_src1 = set([s for s in tmp if comp2(player, s, s1_best)])
+                            higher_src1 = {s for s in tmp if comp2(player, s, s1_best)}
 
                             if len(higher_src1) == 0:
                                 plays.add((move, (s1_best, clamp(s1_best + r2))))
 
         else:
             candidate_src = [s for s in active_positions if s not in home_positions]
-            assert len(candidate_src) == 1, print("Should be 1 instead of {}".format(candidate_src))
+            assert len(candidate_src) == 1, print(f"Should be 1 instead of {candidate_src}")
             candidate_src = candidate_src[0]
             t1 = candidate_src + r1
             t2 = candidate_src + r2
@@ -479,7 +479,7 @@ class Backgammon:
                 tmp = set(list(active_positions)[:])
                 tmp -= {candidate_src}
                 tmp.add(t1)
-                highest_src = set([s for s in tmp if comp2(player, s, s2)])
+                highest_src = {s for s in tmp if comp2(player, s, s2)}
 
                 if s2 in tmp:
                     plays.add(((candidate_src, t1), (s2, clamp(s2 + r2))))
@@ -494,7 +494,7 @@ class Backgammon:
                 tmp = set(list(active_positions)[:])
                 tmp -= {candidate_src}
                 tmp.add(t2)
-                highest_src = set([s for s in tmp if comp2(player, s, s1)])
+                highest_src = {s for s in tmp if comp2(player, s, s1)}
 
                 if s1 in tmp:
                     plays.add(((candidate_src, t2), (s1, clamp(s1 + r1))))
@@ -525,7 +525,7 @@ class Backgammon:
             # I execute the move needed to move all the checkers that are not in home board to home board (in order to update the board - I saved the state)
             self.execute_play(player, out_of_home_move)
             self.players_positions = self.get_players_positions()
-        assert len(list(out_of_home_move)) <= 3, print("Should be <= 3 instead of {}".format(out_of_home_move))
+        assert len(list(out_of_home_move)) <= 3, print(f"Should be <= 3 instead of {out_of_home_move}")
         # number of dice used to move all the checkers that are not in home board to home board (should be <= 3)
         dice_used = len(out_of_home_move)
 
@@ -533,7 +533,7 @@ class Backgammon:
             # All the checkers are in the home board
             active_positions = set(self.players_positions[player])
             # checkers that are higher than position from which I could bear off
-            higher_src = set([s for s in active_positions if comp2(player, s, s1)])
+            higher_src = {s for s in active_positions if comp2(player, s, s1)}
 
             single_moves = self.get_single_moves(player, roll=r)
             double_moves = self.get_double_moves(player, roll=r, single_moves=single_moves)
@@ -561,26 +561,26 @@ class Backgammon:
                         plays.add((move, move, move, move))
                 elif dice_used == 1:
                     if self.board[s1][0] >= 1:
-                        plays.add((out_of_home_move + (move, )))
+                        plays.add(out_of_home_move + (move, ))
                         plays.update([(out_of_home_move + (move, ) + (single, )) for single in single_moves])
                         plays.update([(out_of_home_move + (move, ) + (double[0], ) + (double[1], )) for double in double_moves])
 
                     if self.board[s1][0] >= 2:
-                        plays.add((out_of_home_move + (move, ) + (move, )))
+                        plays.add(out_of_home_move + (move, ) + (move, ))
                         plays.update([(out_of_home_move + (move, ) + (move, ) + (single, )) for single in single_moves])
 
                     if self.board[s1][0] >= 3:
-                        plays.add((out_of_home_move + (move, ) + (move, ) + (move, )))
+                        plays.add(out_of_home_move + (move, ) + (move, ) + (move, ))
                 elif dice_used == 2:
                     if self.board[s1][0] >= 1:
-                        plays.add((out_of_home_move + (move, )))
+                        plays.add(out_of_home_move + (move, ))
                         plays.update([(out_of_home_move + (move, ) + (single, )) for single in single_moves])
 
                     if self.board[s1][0] >= 2:
-                        plays.add((out_of_home_move + (move, ) + (move, )))
+                        plays.add(out_of_home_move + (move, ) + (move, ))
                 elif dice_used == 3:
                     if self.board[s1][0] >= 1:
-                        plays.add((out_of_home_move + (move, )))
+                        plays.add(out_of_home_move + (move, ))
 
                 for s in active_positions:
                     if dice_used == 0:
@@ -605,19 +605,19 @@ class Backgammon:
                         t1 = s + r
                         if self.is_valid(player, t1):
                             if t1 == s1:
-                                plays.add((out_of_home_move + (move,) + ((s, t1), )))
+                                plays.add(out_of_home_move + (move,) + ((s, t1), ))
                                 if self.board[s1][0] >= 1:
-                                    plays.add((out_of_home_move + (move, ) + (move, ) + ((s, t1), )))
+                                    plays.add(out_of_home_move + (move, ) + (move, ) + ((s, t1), ))
                             else:
                                 t2 = t1 + r
                                 if self.is_valid(player, t2):
                                     if t2 == s1:
-                                        plays.add((out_of_home_move + (move, ) + ((s, t1), ) + ((t1, t2), )))
+                                        plays.add(out_of_home_move + (move, ) + ((s, t1), ) + ((t1, t2), ))
                     elif dice_used == 2:
                         t1 = s + r
                         if self.is_valid(player, t1):
                             if t1 == s1:
-                                plays.add((out_of_home_move + (move,) + ((s, t1),)))
+                                plays.add(out_of_home_move + (move,) + ((s, t1),))
 
             # I don't have a checker on the exact position from which I can bear off, but I try to move higher checkers to that position
             for s in higher_src:
@@ -675,7 +675,7 @@ class Backgammon:
                     if self.is_valid(player, t1):
                         if t1 == s1:
                             if self.board[s][0] >= 1:
-                                plays.add((out_of_home_move + ((s, t1),) + (move,)))
+                                plays.add(out_of_home_move + ((s, t1),) + (move,))
 
                                 if self.board[s][0] == 1:
                                     tmp = active_positions - {s}
@@ -685,19 +685,19 @@ class Backgammon:
                                     plays.update([(out_of_home_move + ((s, t1),) + (move, ) + (single, )) for single in single_moves])
 
                             if self.board[s][0] >= 2:
-                                plays.add((out_of_home_move + ((s, t1),) + ((s, t1),) + (move,)))
+                                plays.add(out_of_home_move + ((s, t1),) + ((s, t1),) + (move,))
                         else:
                             t2 = s + r + r
                             if self.is_valid(player, t2):
                                 if t2 == s1:
                                     if self.board[s][0] >= 1:
-                                        plays.add((out_of_home_move + ((s, t1),) + ((t1, t2),) + (move,)))
+                                        plays.add(out_of_home_move + ((s, t1),) + ((t1, t2),) + (move,))
                 elif dice_used == 2:
                     t1 = s + r
                     if self.is_valid(player, t1):
                         if t1 == s1:
                             if self.board[s][0] >= 1:
-                                plays.add((out_of_home_move + ((s, t1),) + (move,)))
+                                plays.add(out_of_home_move + ((s, t1),) + (move,))
             if len(higher_src) == 0:
                 s1_highest = highest(player, [s for s in active_positions if comp1(player, s, r)])
                 active_positions -= {s1_highest}
@@ -775,50 +775,50 @@ class Backgammon:
 
                     elif dice_used == 1:
                         if self.board[s1_highest][0] == 1:
-                            plays.add((out_of_home_move + (move1,)))
+                            plays.add(out_of_home_move + (move1,))
 
                             if s2_highest is not None:
                                 move2 = (s2_highest, clamp(s2_highest + r))
 
                                 if self.board[s2_highest][0] == 1:
-                                    plays.add((out_of_home_move + (move1,) + (move2, )))
+                                    plays.add(out_of_home_move + (move1,) + (move2, ))
 
                                     if s3_highest is not None:
                                         move3 = (s3_highest, clamp(s3_highest + r))
 
                                         if self.board[s3_highest][0] >= 1:
-                                            plays.add((out_of_home_move + (move1, ) + (move2, ) + (move3, )))
+                                            plays.add(out_of_home_move + (move1, ) + (move2, ) + (move3, ))
 
                                 elif self.board[s2_highest][0] >= 2:
-                                    plays.add((out_of_home_move + (move1, ) + (move2, ) + (move2, )))
+                                    plays.add(out_of_home_move + (move1, ) + (move2, ) + (move2, ))
 
                         elif self.board[s1_highest][0] == 2:
-                            plays.add((out_of_home_move + (move1,) + (move1, )))
+                            plays.add(out_of_home_move + (move1,) + (move1, ))
 
                             if s2_highest is not None:
                                 move2 = (s2_highest, clamp(s2_highest + r))
 
                                 if self.board[s2_highest][0] >= 1:
-                                    plays.add((out_of_home_move + (move1,) + (move1,) + (move2, )))
+                                    plays.add(out_of_home_move + (move1,) + (move1,) + (move2, ))
 
                         elif self.board[s1_highest][0] >= 3:
-                            plays.add((out_of_home_move + (move1,) + (move1,) + (move1, )))
+                            plays.add(out_of_home_move + (move1,) + (move1,) + (move1, ))
 
                     elif dice_used == 2:
                         if self.board[s1_highest][0] == 1:
-                            plays.add((out_of_home_move + (move1,)))
+                            plays.add(out_of_home_move + (move1,))
 
                             if s2_highest is not None:
                                 move2 = (s2_highest, clamp(s2_highest + r))
 
                                 if self.board[s2_highest][0] >= 1:
-                                    plays.add((out_of_home_move + (move1,) + (move2,)))
+                                    plays.add(out_of_home_move + (move1,) + (move2,))
 
                         elif self.board[s1_highest][0] >= 2:
-                            plays.add((out_of_home_move + (move1,) + (move1,)))
+                            plays.add(out_of_home_move + (move1,) + (move1,))
 
                     elif dice_used == 3:
-                        plays.add((out_of_home_move + (move1,)))
+                        plays.add(out_of_home_move + (move1,))
 
             if len(higher_src) == 1:
                 if dice_used == 0:
@@ -984,7 +984,7 @@ class Backgammon:
 
                                     if c1 == 1:
                                         s2_highest = highest(player, [s for s in active_positions if comp1(player, s, r)])
-                                        plays.add((out_of_home_move + (move1,) + (move_s1, )))
+                                        plays.add(out_of_home_move + (move1,) + (move_s1, ))
 
                                         if s2_highest is not None:
                                             if self.board[s2_highest][1] != player:
@@ -995,10 +995,10 @@ class Backgammon:
                                             move_s2 = (s2_highest, clamp(s2_highest + r))
 
                                             if c2 >= 1:
-                                                plays.add((out_of_home_move + (move1,) + (move_s1,) + (move_s2, )))
+                                                plays.add(out_of_home_move + (move1,) + (move_s1,) + (move_s2, ))
 
                                     elif c1 >= 2:
-                                        plays.add((out_of_home_move + (move1, ) + (move_s1, ) + (move_s1, )))
+                                        plays.add(out_of_home_move + (move1, ) + (move_s1, ) + (move_s1, ))
 
                             elif self.is_valid(player, t2):
 
@@ -1015,7 +1015,7 @@ class Backgammon:
                                         move_s1 = (s1_highest, clamp(s1_highest + r))
 
                                         if c1 >= 1:
-                                            plays.add((out_of_home_move + (move1, ) + (move2,) + (move_s1, )))
+                                            plays.add(out_of_home_move + (move1, ) + (move2,) + (move_s1, ))
 
                         elif self.board[high_src][0] == 2:
                             if comp3(player, s1, t1):
@@ -1031,7 +1031,7 @@ class Backgammon:
 
                                     if c1 >= 1:
                                         active_positions -= {s1_highest}
-                                        plays.add((out_of_home_move + (move1,) + (move1,) + (move_s1, )))
+                                        plays.add(out_of_home_move + (move1,) + (move1,) + (move_s1, ))
 
                 if dice_used == 2:
                     high_src = list(higher_src)[0]
@@ -1060,7 +1060,7 @@ class Backgammon:
                                     move_s1 = (s1_highest, clamp(s1_highest + r))
 
                                     if c1 >= 1:
-                                        plays.add((out_of_home_move + (move1,) + (move_s1,)))
+                                        plays.add(out_of_home_move + (move1,) + (move_s1,))
             if len(higher_src) == 2:
                 if dice_used == 0:
 
@@ -1183,7 +1183,7 @@ class Backgammon:
                                     if self.board[high_src1][0] == 1 and self.board[high_src2][0] == 1:
 
                                         if c1 >= 1:
-                                            plays.add((out_of_home_move + (move11,) + (move12,) + (move_s1, )))
+                                            plays.add(out_of_home_move + (move11,) + (move12,) + (move_s1, ))
             if len(higher_src) == 3:
                 if dice_used == 0:
                     high_src1 = list(higher_src)[0]
@@ -1220,9 +1220,9 @@ class Backgammon:
     # =================================================================================
     def get_single_moves(self, player, roll, other_move_target=None, player_src=None):
         if player_src is not None:
-            moves = set((s, s + roll) for s in player_src if self.is_valid(player, s + roll))
+            moves = {(s, s + roll) for s in player_src if self.is_valid(player, s + roll)}
         else:
-            moves = set((s, s + roll) for s in list(self.players_positions[player]) if self.is_valid(player, s + roll))
+            moves = {(s, s + roll) for s in list(self.players_positions[player]) if self.is_valid(player, s + roll)}
 
         if other_move_target is not None and self.is_valid(player, other_move_target + roll):
             moves.add((other_move_target, other_move_target + roll))
@@ -1232,7 +1232,7 @@ class Backgammon:
     def get_double_moves(self, player, roll, single_moves):
         moves = set()
         if len(single_moves) > 0:
-            moves = set(((s, t), (t, t + roll)) for (s, t) in single_moves if self.is_valid(player, t + roll))
+            moves = {((s, t), (t, t + roll)) for (s, t) in single_moves if self.is_valid(player, t + roll)}
             moves.update(list(itertools.combinations(single_moves, 2)))
             moves.update([((s, t), (s, t)) for (s, t) in single_moves if self.board[s][0] >= 2])
         return moves
@@ -1260,7 +1260,7 @@ class Backgammon:
                         if (m1 != m2) and self.board[s][0] > 1 and ((s, t) == m1 or (s, t) == m2):
                             moves.add((m1, m2, (s, t)))
 
-        moves = set(tuple(sorted(play, reverse=reverse)) for play in moves)
+        moves = {tuple(sorted(play, reverse=reverse)) for play in moves}
         return moves
 
     def get_bar_plays(self, player, roll):
@@ -1357,11 +1357,11 @@ class Backgammon:
         assert len(bottom_checkers_color) + len(top_checkers_color) == 24
 
         print("| 12 | 13 | 14 | 15 | 16 | 17 | BAR | 18 | 19 | 20 | 21 | 22 | 23 | OFF |")
-        print("|--------Outer Board----------|     |-------P={} Home Board--------|     |".format(TOKEN[BLACK]))
+        print(f"|--------Outer Board----------|     |-------P={TOKEN[BLACK]} Home Board--------|     |")
         self.print_half_board(top_board, top_checkers_color, WHITE, reversed_=1)
         print("|-----------------------------|     |-----------------------------|     |")
         self.print_half_board(bottom_board, bottom_checkers_color, BLACK, reversed_=-1)
-        print("|--------Outer Board----------|     |-------P={} Home Board--------|     |".format(TOKEN[WHITE]))
+        print(f"|--------Outer Board----------|     |-------P={TOKEN[WHITE]} Home Board--------|     |")
         print("| 11 | 10 |  9 |  8 |  7 |  6 | BAR |  5 |  4 |  3 |  2 |  1 |  0 | OFF |\n")
 
     def print_half_board(self, half_board, checkers_color, player, reversed_=-1):
@@ -1369,8 +1369,8 @@ class Backgammon:
         max_length = max(max(half_board), max([self.bar[player], self.off[player]]))
         for i in range(max_length)[::reversed_]:
             row = [str(checkers_color[k]) if half_board[k] > i else " " for k in range(len(half_board))]
-            bar = ["{} ".format(token) if self.bar[player] > i else "  "]
-            off = ["{} ".format(token) if self.off[player] > i else "  "]
+            bar = [f"{token} " if self.bar[player] > i else "  "]
+            off = [f"{token} " if self.off[player] > i else "  "]
             row = row[:6] + bar + row[6:] + off
             print("|  " + " |  ".join(row) + " |")
 
@@ -1402,13 +1402,13 @@ class Backgammon:
         valid_plays.update(normal_plays)
         valid_plays.update(bear_off_plays)
 
-        valid_plays = set(tuple(sorted(play, reverse=reverse)) for play in valid_plays)
+        valid_plays = {tuple(sorted(play, reverse=reverse)) for play in valid_plays}
 
         valid_plays.update(bar_plays)
 
         if len(valid_plays) > 0:
             max_length_move = len(max(valid_plays, key=len))  # select the plays that use the most number of dice
-            top_valid_plays = set(play for play in valid_plays if len(play) == max_length_move)
+            top_valid_plays = {play for play in valid_plays if len(play) == max_length_move}
 
         return top_valid_plays
 
@@ -1499,7 +1499,7 @@ class Backgammon:
         else:
             # features_vector += [1.0, 0.0]
             features_vector += [0.0, 1.0]
-        assert len(features_vector) == 198, print("Should be 198 instead of {}".format(len(features_vector)))
+        assert len(features_vector) == 198, print(f"Should be 198 instead of {len(features_vector)}")
         return features_vector
 
 
@@ -1526,4 +1526,4 @@ def print_assert(game, sum_white, sum_black, bar, off, action, old_board):
     if old_board is not None:
         game.board = old_board
         game.render()
-    print("sum_white={} | sum_black={} | bar={} | off={} | action={}".format(sum_white, sum_black, bar, off, action))
+    print(f"sum_white={sum_white} | sum_black={sum_black} | bar={bar} | off={off} | action={action}")
