@@ -23,10 +23,10 @@ def env(**kwargs):
 class raw_env(RLCardBase):
 
     metadata = {
-        "render.modes": ["human"],
+        "render_modes": ["human"],
         "name": "dou_dizhu_v4",
         "is_parallelizable": False,
-        "video.frames_per_second": 1,
+        "render_fps": 1,
     }
 
     def __init__(self, opponents_hand_visible=False):
