@@ -22,10 +22,10 @@ def env(**kwargs):
 class raw_env(RLCardBase):
 
     metadata = {
-        "render.modes": ["human"],
+        "render_modes": ["human"],
         "name": "mahjong_v4",
         "is_parallelizable": False,
-        "video.frames_per_second": 1,
+        "render_fps": 1,
     }
 
     def __init__(self):
