@@ -20,10 +20,10 @@ def env():
 
 class raw_env(AECEnv):
     metadata = {
-        "render.modes": ["human"],
+        "render_modes": ["human"],
         "name": "tictactoe_v3",
         "is_parallelizable": False,
-        "video.frames_per_second": 1,
+        "render_fps": 1,
     }
 
     def __init__(self):
