@@ -71,9 +71,9 @@ def get_config(map_size, minimap_mode, tag_penalty):
 
 class _parallel_env(magent_parallel_env, EzPickle):
     metadata = {
-        "render.modes": ["human", "rgb_array"],
+        "render_modes": ["human", "rgb_array"],
         'name': "adversarial_pursuit_v3",
-        "video.frames_per_second": 5,
+        "render_fps": 5,
     }
 
     def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
