@@ -71,9 +71,9 @@ def load_config(size, minimap_mode, step_reward, attack_penalty, dead_penalty, a
 
 class _parallel_env(magent_parallel_env, EzPickle):
     metadata = {
-        'render.modes': ['human', 'rgb_array'],
+        'render_modes': ['human', 'rgb_array'],
         'name': "gather_v4",
-        'video.frames_per_second': 5,
+        'render_fps': 5,
     }
 
     def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
