@@ -79,9 +79,9 @@ def get_config(map_size, minimap_mode, tiger_step_recover, deer_attacked):
 
 class _parallel_env(magent_parallel_env, EzPickle):
     metadata = {
-        "render.modes": ["human", "rgb_array"],
+        "render_modes": ["human", "rgb_array"],
         'name': "tiger_deer_v3",
-        "video.frames_per_second": 5,
+        "render_fps": 5,
     }
 
     def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
