@@ -27,7 +27,7 @@ def get_type(agent):
 
 class parallel_env(ParallelEnv):
 
-    metadata = {"render.modes": ["human"], "name": "generated_agents_parallel_v0"}
+    metadata = {"render_modes": ["human"], "name": "generated_agents_parallel_v0"}
 
     def __init__(self, max_cycles=100):
         super().__init__()
