@@ -1,28 +1,43 @@
+import random
 import warnings
 
-from pettingzoo.utils.conversions import aec_to_parallel_wrapper, parallel_to_aec_wrapper
+import numpy as np
+
+from pettingzoo.utils.conversions import (aec_to_parallel_wrapper, parallel_to_aec_wrapper,
+                                          turn_based_aec_to_parallel_wrapper)
 from pettingzoo.utils.wrappers import BaseWrapper
 
 from .api_test import missing_attr_warning
 
 
-def parallel_api_test(par_env, num_cycles=10):
+def sample_action(env, obs, agent):
+    agent_obs = obs[agent]
+    if isinstance(agent_obs, dict) and "action_mask" in agent_obs:
+        legal_actions = np.flatnonzero(agent_obs["action_mask"])
+        if len(legal_actions) == 0:
+            return 0
+        return random.choice(legal_actions)
+    return env.action_space(agent).sample()
+
+
+def parallel_api_test(par_env, num_cycles=1000):
     if not hasattr(par_env, 'possible_agents'):
         warnings.warn(missing_attr_warning.format(name='possible_agents'))
 
     assert not isinstance(par_env.unwrapped, aec_to_parallel_wrapper)
     assert not isinstance(par_env.unwrapped, parallel_to_aec_wrapper)
+    assert not isinstance(par_env.unwrapped, turn_based_aec_to_parallel_wrapper)
     assert not isinstance(par_env.unwrapped, BaseWrapper)
     MAX_RESETS = 2
-    for n_resets in range(MAX_RESETS):
+    for _ in range(MAX_RESETS):
         obs = par_env.reset()
         assert isinstance(obs, dict)
         assert set(obs.keys()) == (set(par_env.agents))
         done = {agent: False for agent in par_env.agents}
         live_agents = set(par_env.agents[:])
         has_finished = set()
-        for i in range(num_cycles):
-            actions = {agent: par_env.action_space(agent).sample() for agent in par_env.agents if agent in done and not done[agent]}
+        for _ in range(num_cycles):
+            actions = {agent: sample_action(par_env, obs, agent) for agent in par_env.agents if agent in done and not done[agent]}
             obs, rew, done, info = par_env.step(actions)
             for agent in par_env.agents:
                 assert agent not in has_finished, "agent cannot be revived once done"
@@ -39,9 +54,13 @@ def parallel_api_test(par_env, num_cycles=10):
             keys = 'observation reward done info'.split()
             vals = [obs, rew, done, info]
             for k, v in zip(keys, vals):
-                if set(v.keys()) == agents_set:
+                key_set = set(v.keys())
+                if key_set == agents_set:
                     continue
-                warnings.warn('Agent was given: {} but was done last turn'.format(k))
+                if len(key_set) < len(agents_set):
+                    warnings.warn('Live agent was not given {}'.format(k))
+                else:
+                    warnings.warn('Agent was given {} but was done last turn'.format(k))
 
             if hasattr(par_env, 'possible_agents'):
                 assert set(par_env.agents).issubset(set(par_env.possible_agents)), "possible_agents defined but does not contain all agents"
